@@ -74,6 +74,7 @@ EVAL_FUNCTIONS_IN_CFG = (
     'eval(',
     'Tags(',
     'str(',
+    'list(',
     'SG_SecurityGroups',
 )
 
@@ -128,6 +129,7 @@ BASE_CFGS = {
     'DBInstance': 'IBOXBASE',
     'ScheduledAction': 'IBOXBASE',
     'ContainerDefinitions': 'IBOXBASE',
+    'AllowedIp': 'IBOXBASE',
 }
 
 INSTANCE_LIST = [
@@ -164,6 +166,7 @@ INSTANCE_LIST = [
     't4g.xlarge', 't4g.2xlarge',
 ]
 
+# Order is VERY important do not CHANGE it!
 CFG_TO_FUNC = {
     'MappingClass': {'module': 'mappings',
                      'func': 'Mappings'},
@@ -285,10 +288,10 @@ CFG_TO_FUNC = {
                          'func': 'SRVD_ServiceDiscovery'},
     'VPCEndpoint': {'module': 'vpc',
                     'func': 'VPC_Endpoint'},
-    'SecurityGroupBase': {'module': 'securitygroup',
-                          'func': 'SG_SecurityGroup'},
+    'SecurityGroup': {'module': 'securitygroup',
+                      'func': 'SG_SecurityGroup'},
     'SecurityGroupIngress': {'module': 'securitygroup',
-                             'func': 'SG_SecurityGroupIngressesExtra'},
+                             'func': 'SG_SecurityGroupIngresses'},
     'VPC': {'module': 'vpc',
             'func': 'VPC_VPC'},
     'CCRLightHouse': {'module': 'cloudformation',
