@@ -4,15 +4,7 @@ from .common import *
 from .shared import (Parameter, do_no_override, get_endvalue, get_expvalue,
                      get_subvalue, auto_get_props, get_condition, add_obj)
 from .securitygroup import (SecurityGroupEcsService,
-                            SecurityGroupRuleEcsService, SG_SecurityGroupsECS)
-
-
-class ECSMountPoint(ecs.MountPoint):
-    def __init__(self, title, key, **kwargs):
-        super().__init__(title, **kwargs)
-        self.ReadOnly = False
-        self.SourceVolume = self.title
-        self.ContainerPath = key['ContainerPath']
+                            SecurityGroupRuleEcsService)
 
 
 class ECSLoadBalancer(ecs.LoadBalancer):
@@ -58,47 +50,11 @@ class ECSContainerDefinition(ecs.ContainerDefinition):
         elif cfg.Image != 'None':
             self.Image = get_endvalue('Image')
 
-        if 'MountPoints' in key:
-            self.MountPoints = [
-                ECSMountPoint(n, key=k) for n, k in key['MountPoints'].items()
-            ]
-
         if 'Name' in key:
             self.Name = get_subvalue('${EnvRole}-${1M}', f'{name}Name')
         else:
             self.Name = Ref('EnvRole')
 
-#        if 'ContainerPort' in key:
-#            PortMapping = ecs.PortMapping(name)
-#            auto_get_props(PortMapping)
-#            if 'HostPort' not in key:
-#                PortMapping.HostPort = If(
-#                    'NetworkModeAwsVpc',
-#                    get_endvalue(f'{name}ContainerPort'),
-#                    0
-#                )
-#            self.PortMappings = [PortMapping]
-
-
-class ECSVolume(ecs.Volume):
-    def __init__(self, title, key, **kwargs):
-        super(ECSVolume, self).__init__(title, **kwargs)
-        self.Name = self.title
-        self.Host = ecs.Host(
-            SourcePath=key['SourcePath']
-        )
-
-
-class ECSNetworkConfiguration(ecs.NetworkConfiguration):
-    def __init__(self, title, **kwargs):
-        super().__init__(title, **kwargs)
-        self.AwsvpcConfiguration = ecs.AwsvpcConfiguration(
-            SecurityGroups=[
-                GetAtt('SecurityGroupEcsService', 'GroupId')
-                ] + SG_SecurityGroupsECS(),
-            Subnets=Split(',', get_expvalue('SubnetsPrivate'))
-        )
-
 
 # ##########################################
 # ### END STACK META CLASSES AND METHODS ###
@@ -186,20 +142,10 @@ def ECS_TaskDefinition(key):
     # Resources
     R_TaskDefinition = ecs.TaskDefinition('TaskDefinitionBase')
     auto_get_props(R_TaskDefinition)
-    R_TaskDefinition.title = 'TaskDefinition'
     R_TaskDefinition.ContainerDefinitions = ECS_ContainerDefinition()
 
-    if cfg.Volumes:
-        Volumes = []
-        for n, v in cfg.Volumes.items():
-            Volume = ECSVolume(n, key=v)
-            Volumes.append(Volume)
-
-        R_TaskDefinition.Volumes = Volumes
-
     add_obj([
-        R_TaskDefinition,
-    ])
+        R_TaskDefinition])
 
 
 def ECS_Service(key):
@@ -253,11 +199,6 @@ def ECS_Service(key):
             r_Service.LoadBalancers.append(
                 ECSLoadBalancer('', scheme='Internal'))
 
-        r_Service.NetworkConfiguration = If(
-            'NetworkModeAwsVpc',
-            ECSNetworkConfiguration(''),
-            Ref('AWS::NoValue'))
-
         add_obj(r_Service)
 
 
