@@ -119,7 +119,7 @@ def get_endvalue(param, ssm=False, condition=False, nocondition=False,
 
     def _get_value():
         # Its not pythonic, but it's only way to avoid circular import problems
-        from .securitygroup import SG_SecurityGroupsTSK
+        from .securitygroup import (SG_SecurityGroupsTSK, SG_SecurityGroupsECS)
 
         if resname:
             IBOXRESNAME = resname
@@ -359,6 +359,7 @@ def auto_get_props(obj, mapname=None, key=None, rootdict=None):
     # IBOXRESNAME can be used in yaml
     IBOXOBJ = obj
     IBOXRESNAME = obj.title
+    IBOXMAPNAME = mapname
 
     def _iboxif(if_wrapper, mapname, value):
         condname = if_wrapper[0].replace('IBOXMAPNAME_', mapname)
@@ -480,8 +481,11 @@ def auto_get_props(obj, mapname=None, key=None, rootdict=None):
             def _condition(k):
                 # this is needed or eval do not find IBOXRESNAME??
                 IBOXRESNAME
+                IBOXMAPNAME
                 for n, v in k.items():
                     n = n.replace('IBOXRESNAME', IBOXRESNAME)
+                    if IBOXMAPNAME:
+                        n = n.replace('IBOXMAPNAME', IBOXMAPNAME)
                     condition = {n: eval(v)}
                     add_obj(condition)
 
@@ -586,6 +590,12 @@ def auto_get_props(obj, mapname=None, key=None, rootdict=None):
             except TypeError:
                 pass
 
+        # title override
+        try:
+            obj.title = key['IBOXTITLE']
+        except Exception:
+            pass
+
     _populate(obj, key, mapname, rootdict)
     return obj
 
