@@ -39,14 +39,12 @@ class SQSQueuePolicy(sqs.QueuePolicy):
 ##
 
 
-class SQS_Queues(object):
-    def __init__(self, key):
-        for n, v in getattr(cfg, key).items():
-            resname = f'{key}{n}'
-            # resources
-            r_Queue = sqs.Queue(resname)
-            auto_get_props(r_Queue, v, recurse=True)
+def SQS_Queues(key):
+    for n, v in getattr(cfg, key).items():
+        resname = f'{key}{n}'
+        # resources
+        r_Queue = sqs.Queue(resname)
+        auto_get_props(r_Queue)
 
-            add_obj([
-                r_Queue,
-            ])
+        add_obj([
+            r_Queue])
